@@ -1,9 +1,3 @@
-
-import requests
-import os
-from datetime import datetime
-import json
-
 """ Host: {name}.sharepoint.com 
 TenantID: Directory or TenantID as per Azure portal
 ClientID: Azure Client ID or Application ID.
@@ -14,7 +8,11 @@ ProxyUse: Whether to use a proxy, true or false
 ProxyUrl: Proxy endpoint to use
 ProxyMethod: https or http, default https
 """
-def sharepoint_download(Host, TenantID, ClientID, Secret, SiteName, LocalFilePath, SharepointFilePath, ProxyUse=False, ProxyUrl="", ProxyMethod="https"):
+def sharepoint_download(Host, TenantID, ClientID, Secret, SiteName,  SharepointFilePath, DownloadMethod="Object", LocalFilePath="", Library="root", ProxyUse=False, ProxyUrl="", ProxyMethod="https"):
+
+    import requests
+    from datetime import datetime
+    import json
 
     # Start the timer
     start  = datetime.now()
@@ -55,7 +53,7 @@ def sharepoint_download(Host, TenantID, ClientID, Secret, SiteName, LocalFilePat
 
     # ======= Get Site ID from Site name ====
     SiteName = SiteName.replace(" ", "")
-    SiteID = requests.request("GET", f"https://graph.microsoft.com/v1.0/sites/{Host}:/sites/{SiteName}", headers=headers, json=payload, proxies=proxies)
+    SiteID = requests.request("GET", f"https://graph.microsoft.com/v1.0/sites/{Host}:/sites/{SiteName}?$select=id", headers=headers, json=payload, proxies=proxies)
     
     if SiteID.status_code != 200:
         duration = datetime.now() - start
@@ -63,11 +61,34 @@ def sharepoint_download(Host, TenantID, ClientID, Secret, SiteName, LocalFilePat
 
     SiteID = SiteID.json()
 
-    # ====== Get Item ID =====
-
+    # ====== Library
     # Note the target path must have a / prefix
     SharepointFilePath = SharepointFilePath.replace(" ", "%20")
-    url = f"https://graph.microsoft.com/v1.0/sites/{SiteID['id']}/drive/root:{SharepointFilePath}"
+    drive = "root"
+    if Library == "root":
+        # ====== Create an upload session =====
+        url = f"https://graph.microsoft.com/v1.0/sites/{SiteID['id']}/drive/root:{SharepointFilePath}"
+    else:
+
+        drive = ""
+        driveID = requests.request("GET", f"https://graph.microsoft.com/v1.0/sites/{SiteID['id']}/drives?$select=name,id", headers=headers, json=payload, proxies=proxies)
+        if driveID.status_code != 200:
+            duration = datetime.now() - start
+            return {"result":"Fail", "reason":"Sharepoint get drives", "duration": str(duration), "status": driveID.status_code, "error": driveID.json()} 
+        
+        driveID = driveID.json()
+        for x in driveID["value"]:
+            if x["name"] == Library:
+                drive = x["id"]
+                break
+        
+        if drive =="":
+            duration = datetime.now() - start
+            return {"result":"Fail", "reason":"Sharepoint no drove found fpr library "+Library, "duration": str(duration)} 
+        
+        url = f"https://graph.microsoft.com/v1.0/sites/{SiteID['id']}/drives/{drive}/root:{SharepointFilePath}"
+
+    # ====== Get Item ID =====
 
     
     ItemID = requests.request("GET", url, headers=headers, json=payload, proxies=proxies)
@@ -81,10 +102,13 @@ def sharepoint_download(Host, TenantID, ClientID, Secret, SiteName, LocalFilePat
 
     # ====== Download file using link =====
     r = requests.get(ItemID["@microsoft.graph.downloadUrl"])  
-    with open(LocalFilePath, 'wb') as f:
-        f.write(r.content)
+
+    if DownloadMethod == "File":
+        with open(LocalFilePath, 'wb') as f:
+            f.write(r.content)
+        duration = datetime.now() - start
+        return {"result":"OK", "duration": str(duration), "status": r.status_code, "FilePath": LocalFilePath} 
 
 
     duration = datetime.now() - start
-
-    return {"result":"OK", "duration": str(duration), "status": r.status_code, "FilePath": LocalFilePath} 
\ No newline at end of file
+    return {"result":"OK", "duration": str(duration), "status": r.status_code, "content": r.content} 
\ No newline at end of file
